@@ -2,7 +2,7 @@
 ##  VT::14.01.2020
 ##
 ##
-##  roxygen2::roxygenise("C:/projects/statproj/R/rrcov")
+##  roxygen2::roxygenise("C:/users/valen/onedrive/myrepo/R/rrcov", load_code=roxygen2:::load_installed)
 ##
 #' Calculates the points for drawing a confidence ellipsoid
 #'
@@ -128,7 +128,7 @@ myscreeplot <- function(rcov, ccov) {
         id.n <- length(which(rd>cutoff))
 
     plot(md, rd, xlab=xlab, ylab=ylab, type="p", ...)
-    .label(md,rd,id.n, labs=labs)
+    .label(md, rd, id.n, labs=labs)
     abline(0, 1, lty=2)
     abline(v=cutoff)
     abline(h=cutoff)
@@ -314,7 +314,7 @@ myscreeplot <- function(rcov, ccov) {
 ##  The differences to tolEllipsePlot() in robustbase are:
 ##  - customizable (titles, limits, labels, etc)
 ##  - can take either a Cov object or a list (aka cov.wt or covMcd)
-##
+##  -
 .myellipse <- function (x, xcov,
     cutoff = NULL,
     id.n = NULL,
@@ -326,8 +326,9 @@ myscreeplot <- function(rcov, ccov) {
     sub="",
     txt.leg=c("robust", "classical"), col.leg = c("red", "blue"),
     lty.leg=c("solid", "dashed"),
-    xlim,
-    ylim, ...)
+    xlim, ylim,
+    off.x, off.y,
+    ...)
 {
     if (is.data.frame(x))
         x <- data.matrix(x)
@@ -371,8 +372,12 @@ myscreeplot <- function(rcov, ccov) {
     rd <- sqrt(mahalanobis(x, x.loc, x.cov, tol = tol))
     if (missing(cutoff) || is.null(cutoff))
         cutoff <- sqrt(qchisq(0.975, df = 2))
-    if (missing(id.n) || is.null(id.n))
+    if (missing(id.n) || is.null(id.n)) {
         id.n <- sum(rd > cutoff)
+        if(n <= 10)             # if less than 10 observations, show all
+            id.n <- n
+    }
+
     ind <- sort(rd, index.return = TRUE)$ix
     ind <- ind[(n - id.n + 1):n]
 
@@ -381,12 +386,25 @@ myscreeplot <- function(rcov, ccov) {
     if(missing(ylim))
         ylim <- y1
 
-    plot(x, xlim = xlim, ylim = ylim, xlab = xlab, ylab = ylab, main = main, sub=sub, ...)
+    plot(x, xlim = xlim, ylim = ylim, xlab = xlab, ylab = ylab, main = main,
+        sub=sub, ...)
+
     box()
     if(id.n > 0) {
-        xrange <- par("usr")
-        xrange <- xrange[2] - xrange[1]
-        text(x[ind, 1] + xrange/50, x[ind, 2], ind)
+        if(missing(off.x))
+        {
+            xrange <- par("usr")
+            xrange <- xrange[2] - xrange[1]
+            off.x <- xrange/50
+        }
+        if(missing(off.y))
+        {
+            xrange <- par("usr")
+            xrange <- xrange[4] - xrange[3]
+            off.y <- xrange/50
+        }
+        labels <- if(!is.null(rownames(x))) rownames(x)[ind] else ind
+        text(x[ind, 1] + off.x, x[ind, 2] + off.y, labels, ...)
     }
 
     points(z2, type = "l", lty = lty.leg[1], col = col.leg[1], ...)
@@ -456,7 +474,10 @@ myscreeplot <- function(rcov, ccov) {
         rect(breaks[-nB], 0, breaks[-1], y, col=hcol)
 
         tryd <- try( d <- density(x, na.rm=TRUE, bw="nrd", adjust=1.2), silent=TRUE)
-        if(class(tryd) != "try-error")
+
+        ## VT::11.08.2022: fix error "Found if() conditions comparing class() to string"
+        ##  if(class(tryd) != "try-error")
+        if(!is(tryd, "try-error"))
         {
             d$y <- d$y/max(d$y)
             lines(d, col=dcol)
@@ -559,6 +580,7 @@ myscreeplot <- function(rcov, ccov) {
         n <- length(y)
         if(missing(id.n))
             id.n <- length(which(y > cutoff))
+
         if(id.n > 0){
             ind <- sort(y, index.return=TRUE)$ix
             ind <- ind[(n-id.n+1):n]
@@ -650,18 +672,18 @@ myscreeplot <- function(rcov, ccov) {
     dd1 <- sqrt(getDistance(obj))                   # robust distances
     if(inherits(obj, "CovMrcd"))
     {
-        vv  <- CovMrcd(X, alpha=1)                  # classical REGULARIZED center and covariance
-        dd2 <- sqrt(getDistance(obj))               # classical Mahalanobis distances
+        vv  <- CovMrcd(X, alpha=1)                   # classical REGULARIZED center and covariance
+        dd2 <- sqrt(getDistance(vv))                 # classical Mahalanobis distances
     } else
     {
-        vv  <- cov.wt(X)                                # classical center and covariance
-        dd2 <- sqrt(mahalanobis(X,vv$center,vv$cov))    # classical Mahalanobis distances
+        vv  <- cov.wt(X)                             # classical center and covariance
+        dd2 <- sqrt(mahalanobis(X,vv$center,vv$cov)) # classical Mahalanobis distances
     }
-    dd  <- c(dd1, dd2)                              # a vector with both robust and classical distances
+    dd  <- c(dd1, dd2)                               # a vector with both robust and classical distances
 
     qq <- sqrt(qchisq(((1:n)-1/3)/(n+1/3), p))
     ind<-c(qq, qq)
-    gr<-as.factor(c(rep(1,n), rep(2,n)))            # 1, 1, ...., 1, 2, 2, ..., 2   - n x 1, n x 2
+    gr<-as.factor(c(rep(1,n), rep(2,n)))             # 1, 1, ...., 1, 2, 2, ..., 2   - n x 1, n x 2
     levels(gr)[1]<-"Robust"
     levels(gr)[2]<-"Classical"
 
